/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime;

import com.intellij.openapi.application.ApplicationManager;
import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.roots.ModuleRootEvent;
import com.intellij.openapi.roots.ModuleRootListener;
import com.intellij.openapi.roots.ProjectRootManager;
import com.intellij.openapi.startup.StartupManager;
import com.intellij.openapi.util.Disposer;
import com.intellij.openapi.wm.ToolWindow;
import com.intellij.openapi.wm.ToolWindowAnchor;
import com.intellij.openapi.wm.ToolWindowManager;
import com.intellij.psi.PsiManager;
import com.intellij.psi.search.GlobalSearchScope;
import net.sourceforge.intellime.util.Constants;

public class J2MEProjectComponent implements ProjectComponent {

    private Project project;
    private ToolWindow toolWindow;
    private J2METoolbar midletView;
    private J2MEModuleRootListener moduleRootListener = new J2MEModuleRootListener();

    public static J2MEProjectComponent getInstance(Project project) {
        return project.getComponent(J2MEProjectComponent.class);
    }

    public J2MEProjectComponent(Project project) {
        this.project = project;
    }

    public void projectOpened() {
        ProjectRootManager.getInstance(project).addModuleRootListener(moduleRootListener, project);
        StartupManager.getInstance(project).runWhenProjectIsInitialized(new Runnable() {
            public void run() {
                moduleRootListener.rootsChanged(null);
            }
        });
    }

    public void projectClosed() {

    }

    public String getComponentName() {
        return Constants.PLUGIN_NAME;
    }

    public void initComponent() {

    }

    public void disposeComponent() {

    }

    /**
     * Quando um novo mdulo for adicionado verifica se  um mdulo J2ME.
     * Caso positivo, mostra a janela de ferramentas
     */
    private class J2MEModuleRootListener implements ModuleRootListener {
        public void beforeRootsChange(ModuleRootEvent event) {

        }

        public void rootsChanged(ModuleRootEvent event) {
            ApplicationManager.getApplication().invokeLater(new Runnable() {
                public void run() {
                    if (!project.isDisposed()) {
                        final PsiManager psiManager = PsiManager.getInstance(project);
                        if (!psiManager.isDisposed()) {
                            // no existe MIDlet no projeto, esconde a janela
                            if (psiManager.findClass(Constants.MIDLET_CLASS, GlobalSearchScope.allScope(project)) == null) {
                                // se a janela existir, esconde
                                if (toolWindow != null) {
                                    toolWindow.hide(null);
                                    toolWindow.setAvailable(false, null);
                                }
                            }
                            // existe ALGUM midLET, exibe a janela
                            else {
                                if (midletView == null) {
                                    ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(project);
                                    midletView = new J2METoolbar();
                                    Disposer.register(project, midletView);
                                    toolWindow = toolWindowManager.registerToolWindow(Constants.TOOL_WINDOW_ID,
                                            midletView.getComponent(), ToolWindowAnchor.RIGHT, project);

                                    toolWindow.setIcon(Constants.TOOLBAR_ICON);
                                }

                                toolWindow.setAvailable(true, null);
                                midletView.openDefault();
                            }
                        }
                    }
                }
            });
        }
    }
}