/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime;

import com.intellij.openapi.Disposable;
import net.sourceforge.intellime.ui.element.FontElement;
import net.sourceforge.intellime.ui.element.ImageElement;
import net.sourceforge.intellime.ui.element.NestedListElement;
import net.sourceforge.intellime.ui.element.TickerElement;
import net.sourceforge.intellime.ui.element.command.*;
import net.sourceforge.intellime.ui.element.item.*;
import net.sourceforge.intellime.ui.element.screen.AlertElement;
import net.sourceforge.intellime.ui.element.screen.FormElement;
import net.sourceforge.intellime.ui.element.screen.ListElement;
import net.sourceforge.intellime.ui.element.screen.TextBoxElement;
import net.sourceforge.intellime.ui.outlook.OutlookBar;
import net.sourceforge.intellime.ui.outlook.OutlookPanel;
import net.sourceforge.intellime.util.Constants;

import javax.swing.*;

public class J2METoolbar implements Disposable {

    private OutlookBar bar = null;

    public J2METoolbar() {
        bar = new OutlookBar();

        OutlookPanel p1 = bar.addPane(J2MEBundle.message("J2METollbar.Screens"));
        OutlookPanel p2 = bar.addPane(J2MEBundle.message("J2METollbar.Commands"));
        OutlookPanel p3 = bar.addPane(J2MEBundle.message("J2METollbar.Items"));
        OutlookPanel p4 = bar.addPane(J2MEBundle.message("J2METollbar.Elements"));
        OutlookPanel p5 = bar.addPane(J2MEBundle.message("J2METollbar.Resources"));

        addScreens(p1);
        addCommands(p2);
        addItems(p3);
        addElements(p4);
        addResources(p5);
    }

    private void addScreens(OutlookPanel panel) {
        panel.addComand(new AlertElement("Alert", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new FormElement("Form", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new ListElement("List", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new TextBoxElement("TextBox", Constants.UNKNOWN_PROPERTY));
    }

    private void addCommands(OutlookPanel panel) {
        panel.addComand(new BackCommand("Back Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new CancelCommand("Cancel Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new ExitCommand("Exit Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new HelpCommand("Help Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new ItemCommand("Item Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new OkCommand("Ok Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new ScreenCommand("Screen Command", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new StopCommand("Stop Command", Constants.UNKNOWN_PROPERTY));
    }

    private void addItems(OutlookPanel panel) {
        //panel.addComand(new ChoiceGroup("Choice Group", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new DateField("Date Field", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new Gauge("Gauge", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new ImageItem("Image Item", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new Spacer("Spacer", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new StringItem("String Item", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new TextField("Text Field", Constants.UNKNOWN_PROPERTY));
    }

    private void addElements(OutlookPanel panel) {
        //panel.addComand("Choice Element", null);
        panel.addComand(new NestedListElement("List Element", Constants.UNKNOWN_PROPERTY));
    }

    private void addResources(OutlookPanel panel) {
        panel.addComand(new FontElement("Font", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new ImageElement("Image", Constants.UNKNOWN_PROPERTY));
        panel.addComand(new TickerElement("Ticker", Constants.UNKNOWN_PROPERTY));
    }

    public JComponent getComponent() {
        return bar;
    }

    public void dispose() {

    }

    public void openDefault() {

    }
}
