/*
 * Copyright 2000-2006 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.action.base;

import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataConstants;
import com.intellij.openapi.project.Project;
import com.intellij.psi.*;
import net.sourceforge.intellime.ui.wizard.impl.ClassWizard;
import net.sourceforge.intellime.util.Constants;
import org.apache.log4j.Logger;

import java.util.Map;

public abstract class NewClassAction extends NewFileAction {

    protected static final Logger logger = Logger.getLogger(NewClassAction.class);

    protected final String className;
    protected final Map overrides;
    protected String packageName;
    protected String templateName;
    protected String fileExtension;

    public NewClassAction(String className) {
        this(className, null, Constants.JAVA_FILE_EXTENSION);
    }

    public NewClassAction(String className, String fileExtension) {
        this(className, null, fileExtension);
    }

    public NewClassAction(String className, String templateName, String fileExtension) {
        this(className, templateName, null, fileExtension);
    }

    public NewClassAction(String className, String templateName, Map overrides, String fileExtension) {
        super();
        this.className = className;
        this.overrides = overrides;
        this.templateName = templateName;
        this.fileExtension = fileExtension;
    }

    protected boolean check(AnActionEvent event) {

        if (!super.check(event)) {
            return false;
        }
        PsiElement psi = (PsiElement) event.getDataContext().getData("psi.Element");

        if (psi instanceof PsiClass) {
            psi = psi.getParent();
        }
        if (psi instanceof PsiJavaFile) {
            psi = psi.getParent();
        }
        if (psi instanceof PsiDirectory) {
            psi = ((PsiDirectory) psi).getPackage();
        }

        if (psi instanceof PsiPackage) {
            packageName = ((PsiPackage) psi).getQualifiedName();
            return true;
        } else {
            packageName = null;
            return event.getDataContext().getData(DataConstants.MODULE) != null;
        }
    }

    public void actionPerformed(AnActionEvent e) {

        final Project project = (Project) e.getDataContext().getData(DataConstants.PROJECT);
        final ClassWizard wizard = new ClassWizard(project, className, packageName, fileExtension);
        wizard.launch(null);
    }
}
