/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram;

import com.intellij.openapi.graph.GraphManager;
import com.intellij.openapi.graph.builder.GraphBuilder;
import com.intellij.openapi.graph.builder.GraphBuilderFactory;
import com.intellij.openapi.graph.builder.components.BasicGraphComponent;
import com.intellij.openapi.graph.view.Graph2D;
import com.intellij.openapi.graph.view.Graph2DView;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.Disposer;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.util.xml.DomElement;
import com.intellij.util.xml.ui.PerspectiveFileEditor;
import net.sourceforge.intellime.ui.dnd.DropTargetListenerImpl;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.awt.dnd.DropTarget;
import java.util.Collection;

public class DiagramFileEditor extends PerspectiveFileEditor {

    // MVC - Model
    private Graph2D graph;
    // MVC - View
    private Graph2DView view;

    private DiagramGraphDataModel model;
    private BasicGraphComponent graphComponent;

    public DiagramFileEditor(Project project, VirtualFile file) {
        super(project, file);

        model = new DiagramGraphDataModel(project, file);
        graph = GraphManager.getGraphManager().createGraph2D();
        view = GraphManager.getGraphManager().createGraph2DView();

        DiagramPresentationModel pres = new DiagramPresentationModel(project, file, graph, model);

        final GraphBuilder graphBuilder =
                GraphBuilderFactory.getInstance(project).createGraphBuilder(graph, view, model, pres);

        model.setGraphBuilder(graphBuilder);

        // drag'n'drop support
        JComponent canvas = graphBuilder.getView().getCanvasComponent();
        new DropTarget(canvas, new DropTargetListenerImpl(graphBuilder));

        // ddges deletetion support
        canvas.addKeyListener(new DiagramKeyListener(project, graphBuilder));

        graphComponent = new BasicGraphComponent(graphBuilder);

        // apply layout
        model.doLayout();

        Disposer.register(this, graphComponent);
    }

    @Nullable
    protected DomElement getSelectedDomElement() {
        return null;
    }

    protected void setSelectedDomElement(DomElement domElement) {

    }

    @NotNull
    protected JComponent createCustomComponent() {
        return graphComponent.getComponent();
    }

    @Nullable
    public JComponent getPreferredFocusedComponent() {
        return null;
    }

    @NonNls
    @NotNull
    public String getName() {
        return DiagramFileEditor.class.getSimpleName();
    }

    public void commit() {

    }

    public void reset() {

    }

    public Collection<Node> getNodes() {
        return model.getNodes();
    }

    public Collection<Edge> getEdges() {
        return model.getEdges();
    }
}
