/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram;

import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.openapi.fileEditor.*;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.Disposer;
import com.intellij.openapi.vfs.VirtualFile;
import net.sourceforge.intellime.util.Constants;
import net.sourceforge.intellime.util.Utils;
import org.jdom.Element;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

public class DiagramFileEditorProvider implements ApplicationComponent, FileEditorProvider {

    public DiagramFileEditorProvider() {

    }

    public void initComponent() {

    }

    public void disposeComponent() {

    }

    public String getComponentName() {
        return DiagramFileEditorProvider.class.getSimpleName();
    }

    public boolean accept(@NotNull Project project, @NotNull VirtualFile file) {
        return Utils.isDiagramFile(file);
    }

    @NotNull
    public FileEditor createEditor(@NotNull Project project, @NotNull VirtualFile file) {
        FileDocumentManager.getInstance()
                .saveDocument(FileDocumentManager.getInstance().getDocument(file));

        return new DiagramFileEditor(project, file);
    }

    public void disposeEditor(@NotNull FileEditor editor) {
        Disposer.dispose((DiagramFileEditor) editor);
    }

    @NotNull
    public FileEditorState readState(@NotNull Element element, @NotNull Project project, @NotNull VirtualFile virtualFile) {
        return FileEditorState.INSTANCE;
    }

    public void writeState(@NotNull FileEditorState fileEditorState, @NotNull Project project, @NotNull Element element) {

    }

    @NotNull
    @NonNls
    public String getEditorTypeId() {
        return Constants.DIAGRAM_FILE_EXTENSION;
    }

    @NotNull
    public FileEditorPolicy getPolicy() {
        return FileEditorPolicy.PLACE_BEFORE_DEFAULT_EDITOR;
    }
}
