/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram;

import com.intellij.openapi.graph.base.Edge;
import com.intellij.openapi.graph.builder.GraphBuilder;
import com.intellij.openapi.graph.builder.util.GraphViewUtil;
import com.intellij.openapi.graph.builder.util.GraphWrapperUtil;
import com.intellij.openapi.graph.view.Graph2D;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.DialogWrapper;
import com.intellij.openapi.ui.Messages;
import net.sourceforge.intellime.J2MEBundle;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.List;

public class DiagramKeyListener implements KeyListener {

    private Graph2D graph;
    private DiagramGraphDataModel model;
    private GraphWrapperUtil util;

    public DiagramKeyListener(Project project, GraphBuilder graphBuilder) {
        graph = graphBuilder.getGraph();
        model = (DiagramGraphDataModel) graphBuilder.getGraphDataModel();
        util = GraphWrapperUtil.getInstance(project);
    }

    public void keyPressed(KeyEvent keyEvent) {
        if (keyEvent.getKeyCode() == KeyEvent.VK_DELETE) {
            if (Messages.showOkCancelDialog(
                    J2MEBundle.message("ui.DiagramKeyListener.removeLabel"),
                    J2MEBundle.message("ui.DiagramKeyListener.removeTitle"),
                    Messages.getQuestionIcon()) == DialogWrapper.OK_EXIT_CODE) {

                removeEdges();
            }
        }
    }

    public void keyTyped(KeyEvent keyEvent) {
    }

    public void keyReleased(KeyEvent keyEvent) {
    }

    private void removeEdges() {
        List<Edge> edges = GraphViewUtil.getSelectedEdges(graph);
        for (int i = edges.size() - 1; i >= 0; i--) {
            net.sourceforge.intellime.ui.diagram.Edge e =
                    util.getEdgeObject(graph, edges.get(i));
            model.removeEdge(e, true);
        }

        graph.getCurrentView().updateView();
    }
}
