/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram;

import com.intellij.openapi.graph.GraphManager;
import com.intellij.openapi.graph.base.Graph;
import com.intellij.openapi.graph.builder.DeleteProvider;
import com.intellij.openapi.graph.builder.components.BasicGraphPresentationModel;
import com.intellij.openapi.graph.builder.util.GraphViewUtil;
import com.intellij.openapi.graph.view.*;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.ModificationTracker;
import net.sourceforge.intellime.ui.diagram.renderer.J2MEElementNodeRenderer;
import net.sourceforge.intellime.ui.editor.NodeEditorDialog;
import org.jetbrains.annotations.NotNull;

public class DiagramPresentationModel extends BasicGraphPresentationModel<Node, Edge> {

    private final J2MEElementNodeRenderer renderer;
    private DeleteProvider deleteProvider;
    private DiagramGraphDataModel model;

    public DiagramPresentationModel(Project project, ModificationTracker tracker,
                                    Graph graph, DiagramGraphDataModel model) {
        super(graph);
        this.model = model;
        renderer = new J2MEElementNodeRenderer(project, tracker);
        deleteProvider = new DiagramDeleteProvider(model);
    }

    public void customizeSettings(final Graph2DView view, final EditMode editMode) {
        setShowEdgeLabels(true);
    }

    public boolean editNode(Node node) {
        NodeEditorDialog editor = new NodeEditorDialog(model, node);

        if (!editor.isEmpty()) {
            editor.show();
            if (editor.isOK()) {
                getGraphBuilder().updateGraph();
            }
        }

        return !editor.isEmpty();
    }

    public NodeRealizer getNodeRealizer(Node node) {
        return GraphViewUtil.createNodeRealizer("DEFAULT", renderer);
    }

    public DeleteProvider getDeleteProvider() {
        return deleteProvider;
    }

    @NotNull
    public EdgeRealizer getEdgeRealizer(Edge edge) {
        final GraphManager graphManager = GraphManager.getGraphManager();
        final PolyLineEdgeRealizer edgeRealizer =
                graphManager.createPolyLineEdgeRealizer();

        EdgeLabel edgeLabel = graphManager.createEdgeLabel(edge.getName());
        edgeRealizer.addLabel(edgeLabel);

        edgeLabel.setModel(EdgeLabel.CENTER_SLIDER);
        edgeLabel.setPosition(EdgeLabel.DYNAMIC);
        edgeRealizer.setTargetArrow(Arrow.STANDARD);
        edgeRealizer.setLineType(LineType.LINE_1);

        return edgeRealizer;
    }
}
