/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram;

import net.sourceforge.intellime.ui.element.command.CommandElement;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;

public class Edge {

    private Node source;
    private Node target;
    private CommandElement command;

    public Edge(Node source, Node target) {
        this.source = source;
        this.target = target;
    }

    @Nullable
    public Icon getIcon() {
        return null;
    }

    public String getName() {
        return source.getLabel() + (command == null ? "" : " [" + command.getLabel() + "]") + " --> " + target.getLabel();
    }

    public Node getSource() {
        return source;
    }

    public Node getTarget() {
        return target;
    }

    public CommandElement getCommand() {
        return command;
    }

    public void setCommand(CommandElement command) {
        this.command = command;
    }

    // o edge est relacionado a um comando
    public boolean isValid() {
        return command != null && source.contains(command);
    }

    public String toString() {
        return source.getProperty() + (command == null ? "" : " [" + command.getProperty() + "]") + " --> " + target.getProperty();
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Edge edge = (Edge) o;

        if (command != null ? !command.equals(edge.command) : edge.command != null) return false;
        if (source != null ? !source.equals(edge.source) : edge.source != null) return false;
        if (target != null ? !target.equals(edge.target) : edge.target != null) return false;

        return true;
    }

    public int hashCode() {
        int result;
        result = (source != null ? source.hashCode() : 0);
        result = 31 * result + (target != null ? target.hashCode() : 0);
        result = 31 * result + (command != null ? command.hashCode() : 0);
        return result;
    }
}
