/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram;

import net.sourceforge.intellime.ui.element.J2MEElement;
import net.sourceforge.intellime.ui.element.NestedListElement;
import net.sourceforge.intellime.ui.element.command.CommandElement;
import net.sourceforge.intellime.ui.element.screen.ScreenElement;

import javax.swing.*;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Node {

    private ScreenElement screenElement;
    private List<Edge> sources = new ArrayList<Edge>();
    private List<Edge> targets = new ArrayList<Edge>();
    private Map<Edge, Edge> linkedEdges = new HashMap<Edge, Edge>();

    public Node(ScreenElement screenElement) {
        this.screenElement = screenElement;
    }

    public ScreenElement getScreenElement() {
        return screenElement;
    }

    public Icon getIcon() {
        return screenElement.getIcon();
    }

    public String getLabel() {
        return screenElement.getLabel();
    }

    public List<Edge> getSources() {
        return sources;
    }

    public List<Edge> getTargets() {
        return targets;
    }

    public void add(J2MEElement element) {
        screenElement.add(element);
    }

    public boolean remove(J2MEElement element) {
        return screenElement.remove(element);
    }

    public boolean contains(J2MEElement element) {
        return screenElement.contains(element);
    }

    public List<CommandElement> getCommands() {
        return screenElement.getCommands();
    }

    public List<NestedListElement> getNestedListElements() {
        return screenElement.getNestedListElements();
    }

    public List<J2MEElement> getElements() {
        return screenElement.getElements();
    }

    public String toString() {
        return screenElement.getLabel();
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Node node = (Node) o;

        if (screenElement != null ? !screenElement.equals(node.screenElement) : node.screenElement != null)
            return false;

        return true;
    }

    public int hashCode() {
        return (screenElement != null ? screenElement.hashCode() : 0);
    }

    public String getProperty() {
        return screenElement.getProperty();
    }

    public void addSource(Edge e) {
        sources.add(e);
    }

    public boolean removeSource(Edge e) {
        removeLinkedEdge(e);
        return sources.remove(e);
    }

    public void addTarget(Edge e) {
        targets.add(e);
    }

    public boolean removeTarget(Edge e) {
        removeLinkedEdge(e);
        return targets.remove(e);
    }

    public void putLinkedEdge(Edge target, Edge source) {
        linkedEdges.put(target, source);
    }

    public Edge getLinkedEdge(Edge target) {
        return linkedEdges.get(target);
    }

    public Map<Edge, Edge> getLinkedEdges() {
        return linkedEdges;
    }

    private void removeLinkedEdge(Edge e) {
        if (linkedEdges.containsKey(e)) {
            linkedEdges.remove(e);
        } else if (linkedEdges.containsValue(e)) {
            for (Map.Entry<Edge, Edge> entry : linkedEdges.entrySet()) {
                if (e.equals(entry.getValue())) {
                    linkedEdges.remove(entry.getKey());
                    break;
                }
            }
        }
    }

}
