/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram.helper;

import com.intellij.openapi.editor.Document;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.PsiDocumentManager;
import com.intellij.psi.PsiFile;
import com.intellij.psi.PsiManager;
import com.intellij.psi.xml.XmlFile;
import com.intellij.psi.xml.XmlTag;
import com.intellij.util.IncorrectOperationException;
import net.sourceforge.intellime.ui.diagram.Edge;
import net.sourceforge.intellime.ui.diagram.Node;
import net.sourceforge.intellime.util.RunnableHelper;

import java.util.List;

public class DiagramSerializer {

    private Project project;
    private XmlFile xmlFile;

    public DiagramSerializer(Project project, VirtualFile virtualFile) {
        this.project = project;

        PsiFile psiFile = PsiManager.getInstance(project).findFile(virtualFile);
        if (psiFile instanceof XmlFile) {
            xmlFile = (XmlFile) psiFile;
        }
    }

    public void serialize(List<Node> nodes, List<Edge> edges) {
        if (xmlFile != null && xmlFile.isWritable()) {
            cleanFile();
            XmlTagFactory factory = XmlTagFactory.getInstance(project);

            if (factory != null) {
                try {
                    XmlTag xmlTagDiagram = factory.createDiagramTag();
                    for (Node n : nodes) {
                        XmlTag xmlTagNode = factory.createNodeTag(n);
                        xmlTagDiagram.add(xmlTagNode);
                    }
                    for (Edge e : edges) {
                        XmlTag xmlTagEdge = factory.createEdgeTag(e);
                        xmlTagDiagram.add(xmlTagEdge);
                    }
                    writeFile(xmlTagDiagram);
                } catch (IncorrectOperationException e) {
                    System.out.println(e.getMessage());
                }
            }
        }
    }

    private void cleanFile() {
        final Document document = PsiDocumentManager.getInstance(project).getDocument(xmlFile);
        RunnableHelper.runWriteCommand(project, new Runnable() {
            public void run() {
                document.setText("");
                PsiDocumentManager.getInstance(project).commitDocument(document);
            }
        });
    }

    private void writeFile(final XmlTag xmlTagIntelliME) {
        RunnableHelper.runWriteCommand(project, new Runnable() {
            public void run() {
                try {
                    xmlFile.add(xmlTagIntelliME);
                } catch (IncorrectOperationException e) {
                    System.out.println(e.getMessage());
                }
            }
        });
    }

}
