/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.diagram.renderer;

import com.intellij.openapi.graph.builder.renderer.BasicGraphNodeRenderer;
import com.intellij.openapi.graph.builder.util.GraphWrapperUtil;
import com.intellij.openapi.graph.view.Graph2DView;
import com.intellij.openapi.graph.view.NodeRealizer;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.ModificationTracker;
import net.sourceforge.intellime.ui.diagram.Node;
import net.sourceforge.intellime.ui.element.J2MEElement;
import net.sourceforge.intellime.ui.element.MIDletElement;
import net.sourceforge.intellime.ui.dnd.DropTargetListenerImpl;

import javax.swing.*;
import java.awt.*;
import java.util.List;

public class J2MEElementNodeRenderer extends BasicGraphNodeRenderer<Node> {

    public static Node DRAG_OVER_NODE = null;
    
    private Project project;

    public J2MEElementNodeRenderer(Project project, ModificationTracker tracker) {
        super(project, tracker);
        this.project = project;
    }

    protected Color getBackground(Node node) {
        return Color.LIGHT_GRAY;
    }

    protected Icon getIcon(Node node) {
        final Icon icon = node.getIcon();
        return icon == null ? super.getIcon(node) : icon;
    }

    protected String getNodeName(Node node) {
        return node.getLabel();
    }

    protected JComponent getLabelPanel(NodeRealizer nodeRealizer) {
        return super.getLabelPanel(nodeRealizer);
    }

    public JComponent getNodeCellRendererComponent(Graph2DView graph2DView, NodeRealizer nodeRealizer, Object object, boolean b) {

        // componente atual
        JComponent current = super.getRendererComponent(graph2DView, nodeRealizer, object, b);

        // n atual
        Node node = GraphWrapperUtil.getInstance(project)
                .getNodeObject(graph2DView.getGraph2D(), nodeRealizer.getNode());

        tuneText(current, (node.getScreenElement() instanceof MIDletElement));

        // elementos associados ao n
        List<J2MEElement> elements = node.getElements();

        if (elements != null && elements.size() > 0) {
            JList list = new JList(elements.toArray());
            list.setCellRenderer(new ColoredListCellRenderer());
            list.setBorder(BorderFactory.createLineBorder(Color.LIGHT_GRAY, 1));
            current.add(list, BorderLayout.SOUTH);
        }

        updateBorder(current, node);

        return current;
    }

    private void updateBorder(JComponent current, Node node) {
        if (DRAG_OVER_NODE != null && DRAG_OVER_NODE.equals(node)) {
            current.setBorder(BorderFactory.createLineBorder(Color.RED, 3));
        }
        else {
            current.setBorder(null);
        }
    }

    private void tuneText(JComponent component, boolean midlet) {
        Component[] components = component.getComponents();
        for (Component c : components) {
            if (c instanceof JComponent) {
                if (c instanceof JLabel) {
                    JLabel label = (JLabel) c;
                    Font font = label.getFont();
                    label.setFont(new Font(font.getName(), Font.BOLD, font.getSize()));
                    if (midlet) {
                        label.setForeground(Color.BLUE);
                    }
                }
                tuneText((JComponent) c, midlet);
            }
        }
    }
}