/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.dialog;

import com.intellij.openapi.ui.Messages;
import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.UiUtils;
import net.sourceforge.intellime.util.Utils;

import javax.swing.*;
import java.awt.*;

public class BasicPropertiesPanel extends JPanel {

    private JTextField txtProperty;
    private JTextField txtLabel;

    public BasicPropertiesPanel() {
        initialize();
    }

    private void initialize() {
        setLayout(new BorderLayout());

        // label do novo elemento
        JPanel northPanel = new JPanel();
        northPanel.setLayout(new BorderLayout());
        JLabel lblLabel = new JLabel(J2MEBundle.message("ui.BasicPropertiesPanel.label"));
        lblLabel.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 5));
        lblLabel.setHorizontalAlignment(JButton.RIGHT);
        UiUtils.setWidth(lblLabel, 70);
        northPanel.add(lblLabel, BorderLayout.WEST);

        txtLabel = new JTextField();
        UiUtils.setWidth(txtLabel, 200);
        northPanel.add(txtLabel, BorderLayout.CENTER);
        northPanel.setBorder(BorderFactory.createEmptyBorder(0, 0, 5, 0));

        add(northPanel, BorderLayout.NORTH);

        // property do novo elemento
        JPanel centerPanel = new JPanel();
        centerPanel.setLayout(new BorderLayout());
        JLabel lblProperty = new JLabel(J2MEBundle.message("ui.BasicPropertiesPanel.property"));
        lblProperty.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 5));
        lblProperty.setHorizontalAlignment(JButton.RIGHT);
        UiUtils.setWidth(lblProperty, 70);
        centerPanel.add(lblProperty, BorderLayout.WEST);

        txtProperty = new JTextField();
        UiUtils.setWidth(txtProperty, 200);
        centerPanel.add(txtProperty, BorderLayout.CENTER);

        add(centerPanel, BorderLayout.CENTER);
    }

    public boolean validValues() {
        boolean valid = false;

        // invalid label
        if (txtLabel.getText() == null || "".equals(txtLabel.getText().trim())) {
            Messages.showErrorDialog(
                    J2MEBundle.message("ui.NewElementDialog.invalidLabel", txtProperty.getText()),
                    J2MEBundle.message("ui.NewElementDialog.invalidLabelTitle"));
        }
        // invalid property
        else if (!Utils.isJavaIdentifier(txtProperty.getText())) {
            Messages.showErrorDialog(
                    J2MEBundle.message("ui.NewElementDialog.invalidProperty", txtProperty.getText()),
                    J2MEBundle.message("ui.NewElementDialog.invalidPropertyTitle"));
        } else {
            valid = true;
        }

        return valid;
    }

    public String propertyValue() {
        return txtProperty.getText();
    }

    public String labelValue() {
        return txtLabel.getText();
    }
}
