/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.dialog;

import net.sourceforge.intellime.ui.UiUtils;

import javax.swing.*;
import java.awt.*;
import java.util.List;

public class ComboPanel<E> extends JPanel {

    private JComboBox combo;
    private String label;
    private List<E> elements;

    public ComboPanel(String label, List<E> elements, boolean select) {
        this.label = label;
        this.elements = elements;
        initialize(select);
    }

    public ComboPanel(String label, List<E> elements) {
        this(label, elements, true);
    }

    private void initialize(boolean select) {
        setLayout(new BorderLayout());
        setBorder(BorderFactory.createEmptyBorder(0, 0, 5, 0));

        // seleo do n
        JPanel panel = new JPanel();
        panel.setLayout(new BorderLayout());
        JLabel label3 = new JLabel(label);
        label3.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 5));
        label3.setHorizontalAlignment(JButton.RIGHT);
        UiUtils.setWidth(label3, 70);
        panel.add(label3, BorderLayout.WEST);

        combo = new JComboBox();
        panel.add(combo, BorderLayout.CENTER);
        fill(combo, elements, select);

        add(panel, BorderLayout.CENTER);
    }

    protected void fill(JComboBox combo, List elements, boolean select) {
        if (elements != null && combo != null) {
            for (Object o : elements) {
                combo.addItem(o);
            }
            if (!select) {
                combo.setSelectedIndex(-1);
            }
        }
    }

    public void setSelected(E value) {
        combo.setSelectedItem(value);
    }

    public E selectedValue() {
        return (E) combo.getSelectedItem();
    }

    public boolean validSelection() {
        return combo != null && combo.getSelectedItem() == null;
    }
}
