/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.dialog;

import com.intellij.openapi.ui.Messages;
import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.element.command.*;
import net.sourceforge.intellime.util.Constants;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.util.ArrayList;
import java.util.List;

public class NewCommandDialog extends DialogBase<CommandElement> {

    private ComboPanel comboPanel;
    private BasicPropertiesPanel basicPanel;

    public NewCommandDialog() {
        super();
        setTitle(J2MEBundle.message("ui.NewCommandDialog.title"));
        setModal(true);
        init();
    }

    private List<CommandElement> avaliableCommands() {
        List<CommandElement> commands = new ArrayList<CommandElement>();

        commands.add(new BackCommand("Back Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new CancelCommand("Cancel Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new ExitCommand("Exit Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new HelpCommand("Help Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new ItemCommand("Item Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new OkCommand("Ok Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new ScreenCommand("Screen Command", Constants.UNKNOWN_PROPERTY));
        commands.add(new StopCommand("Stop Command", Constants.UNKNOWN_PROPERTY));

        return commands;
    }

    protected void doOKAction() {
        // label & property
        if (basicPanel.validValues()) {
            // invalid node
            if (comboPanel.validSelection()) {
                Messages.showErrorDialog(
                        J2MEBundle.message("ui.NewCommandDialog.invalidCommand"),
                        J2MEBundle.message("ui.NewCommandDialog.invalidCommandTitle"));
            }
            // everything ok
            else {
                setupObject();
                // close dialog
                super.doOKAction();
            }
        }
    }

    protected void setupObject() {
        object = (CommandElement) comboPanel.selectedValue();
        object.setLabel(basicPanel.labelValue());
        object.setProperty(basicPanel.propertyValue());
    }

    protected JComponent createNorthPanel() {
        if (comboPanel == null) {
            comboPanel = new ComboPanel<CommandElement>(
                    J2MEBundle.message("ui.NewCommandDialog.commandType"),
                    avaliableCommands());
        }

        return comboPanel;
    }

    @Nullable
    protected JComponent createCenterPanel() {
        if (basicPanel == null) {
            basicPanel = new BasicPropertiesPanel();
        }

        return basicPanel;
    }

    public CommandElement selectedCommand() {
        return (CommandElement) comboPanel.selectedValue();
    }
}
