/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.dialog;

import com.intellij.openapi.ui.Messages;
import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.diagram.Node;
import net.sourceforge.intellime.ui.dialog.filter.NodeFilterFactory;
import net.sourceforge.intellime.ui.element.J2MEElement;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.util.List;

public class NewElementDialog extends DialogBase<J2MEElement> {

    private List<Node> nodes;
    private BasicPropertiesPanel basicPanel;
    private ComboPanel<Node> comboPanel;

    public NewElementDialog(J2MEElement element, List<Node> nodes) {
        this(element, nodes, null);
    }

    public NewElementDialog(J2MEElement element, List<Node> nodes, Node node) {
        super();
        this.object = element;
        this.nodes = NodeFilterFactory.getFilter(element).filter(nodes);
        setTitle(J2MEBundle.message("ui.NewElementDialog.title"));
        setModal(true);
        init();
        if (node != null) {
            comboPanel.setSelected(node);
        }
    }

    protected JComponent createNorthPanel() {
        if (comboPanel == null) {
            comboPanel = new ComboPanel<Node>(
                    J2MEBundle.message("ui.NewElementDialog.targetNode"),
                    nodes, false);
        }

        return comboPanel;
    }

    @Nullable
    protected JComponent createCenterPanel() {
        if (basicPanel == null) {
            basicPanel = new BasicPropertiesPanel();
        }

        return basicPanel;
    }

    protected void doOKAction() {
        // label & property
        if (basicPanel.validValues()) {
            // invalid node
            if (comboPanel.validSelection()) {
                Messages.showErrorDialog(
                        J2MEBundle.message("ui.NewElementDialog.invalidNode"),
                        J2MEBundle.message("ui.NewElementDialog.invalidNodeTitle"));
            }
            // everything ok
            else {
                setupObject();
                // close dialog
                super.doOKAction();
            }
        }
    }

    protected void setupObject() {
        object.setLabel(basicPanel.labelValue());
        object.setProperty(basicPanel.propertyValue());
    }

    public Node selectedNode() {
        return comboPanel.selectedValue();
    }
}
