/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.dnd;

import net.sourceforge.intellime.ui.element.J2MEElement;

import javax.swing.*;
import java.awt.dnd.DnDConstants;
import java.awt.dnd.DragGestureListener;
import java.awt.dnd.DragSource;
import java.awt.dnd.DragSourceListener;

public class DragToggleButton extends JToggleButton {

    private DragSource dragSource;
    private DragGestureListener dgListener;
    private DragSourceListener dsListener;
    private J2MEElement element;

    public DragToggleButton(J2MEElement element) {
        super(element.getLabel(), element.getIcon());
        this.setToolTipText(element.getJ2MEClassName());

        this.element = element;
        this.dragSource = DragSource.getDefaultDragSource();
        this.dgListener = new DragGestureListenerImpl(this);
        this.dsListener = new DragSourceListenerImpl();

        // component, action, listener
        this.dragSource.createDefaultDragGestureRecognizer(
                this, DnDConstants.ACTION_COPY_OR_MOVE, this.dgListener);
    }

    public DragGestureListener getDgListener() {
        return dgListener;
    }

    public DragSourceListener getDsListener() {
        return dsListener;
    }

    public J2MEElement getElement() {
        return element;
    }
}
