/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.dnd;

import net.sourceforge.intellime.ui.element.J2MEElement;
import net.sourceforge.intellime.util.Constants;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

public class J2MEElementTransferable implements Transferable {
    // This DataFlavor object is used when we transfer Color objects directly
    protected static DataFlavor elementFlavor =
            new DataFlavor(J2MEElement.class, Constants.ELEMENT_NAME);

    // These are the data flavors we support.
    protected static DataFlavor[] supportedFlavors = {elementFlavor};

    private J2MEElement element;

    /**
     * Create a new TransferableColor that encapsulates the specified element
     *
     * @param element J2ME element
     */
    public J2MEElementTransferable(J2MEElement element) {
        this.element = element;
    }

    /**
     * Return a list of DataFlavors we can support
     */
    public DataFlavor[] getTransferDataFlavors() {
        return supportedFlavors;
    }

    /**
     * Check whether a specified DataFlavor is available
     */
    public boolean isDataFlavorSupported(DataFlavor flavor) {
        return (flavor.equals(elementFlavor));
    }

    /**
     * Transfer the data.  Given a specified DataFlavor, return an Object
     * appropriate for that flavor.  Throw UnsupportedFlavorException if we
     * don't support the requested flavor.
     */
    public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException, IOException {
        if (flavor.equals(elementFlavor)) {
            return element;
        } else {
            throw new UnsupportedFlavorException(flavor);
        }
    }
}
