/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.editor;

import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.diagram.DiagramGraphDataModel;
import net.sourceforge.intellime.ui.diagram.Edge;
import net.sourceforge.intellime.ui.diagram.Node;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableColumn;
import java.awt.*;
import java.util.Collection;

public class AlertEdgeEditorDialog extends EditorDialogBase<Edge> {

    private JPanel panel;

    public AlertEdgeEditorDialog(DiagramGraphDataModel model, Edge edge) {
        super(model, edge);
        setTitle(J2MEBundle.message("ui.editor.NodeEditorDialog.title"));
    }

    @Nullable
    protected JComponent createCenterPanel() {
        if (panel == null) {
            panel = new JPanel();
            panel.setLayout(new BorderLayout());

            Node node = editing.getTarget();
            JTable table = new JTable(new NodeTableModel(node, node.getSources()));
            setUpColumn(table, table.getColumnModel().getColumn(1));

            panel.add(new JScrollPane(table), BorderLayout.CENTER);
            panel.setPreferredSize(new Dimension(250, 100));
        }

        return panel;
    }

    private void setUpColumn(JTable table, TableColumn column) {
        Collection<Edge> edges = editing.getTarget().getLinkedEdges().values();
        if (edges != null && edges.size() > 0) {
            JComboBox combo = new JComboBox();

            // existing commands
            combo.addItem(null);
            for (Edge edge : edges) {
                combo.addItem(edge.getTarget());
            }

            column.setCellEditor(new DefaultCellEditor(combo));

            DefaultTableCellRenderer renderer =
                    new DefaultTableCellRenderer();

            column.setCellRenderer(renderer);

            /*
            TableModel tableModel = table.getModel();
            for (Edge edge : edges) {
                for (int i = 0; i < tableModel.getRowCount(); i++) {
                    CommandElement command = (CommandElement) tableModel.getValueAt(i, 0);
                    // select corresponding target on combo
                    if (command.equals(edge.getCommand())) {
                        table.setValueAt(edge.getTarget(), i, 1);
                    }
                }
            }
            */
        }
    }

    protected void performAction() {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    protected boolean validSelection() {
        return false;  //To change body of implemented methods use File | Settings | File Templates.
    }
}
