/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.editor;

import com.intellij.openapi.ui.Messages;
import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.diagram.DiagramGraphDataModel;
import net.sourceforge.intellime.ui.diagram.Edge;
import net.sourceforge.intellime.ui.dialog.NewCommandDialog;
import net.sourceforge.intellime.ui.element.command.CommandElement;
import net.sourceforge.intellime.ui.element.screen.ScreenElement;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;

public class EdgeEditorDialogBase extends EditorDialogBase<Edge> implements ActionListener {

    private JPanel panel;
    private JComboBox combo;
    private CommandElement command;

    public EdgeEditorDialogBase(DiagramGraphDataModel model, Edge edge) {
        super(model, edge);
        setTitle(J2MEBundle.message("ui.editor.EdgeEditorDialogBase.title"));
    }

    protected ScreenElement getSourceElement() {
        return editing.getSource().getScreenElement();
    }

    protected ScreenElement getTargetElement() {
        return editing.getTarget().getScreenElement();
    }

    protected JComponent createCenterPanel() {
        if (panel == null) {
            panel = new JPanel();
            panel.setLayout(new BorderLayout());
            panel.add(new JLabel(J2MEBundle.message("ui.editor.EdgeEditorDialogBase.command")),
                    BorderLayout.WEST);
            combo = new JComboBox();
            panel.add(combo, BorderLayout.CENTER);

            fill(combo);

            combo.addActionListener(this);
        }
        return panel;
    }

    private void fill(JComboBox combo) {
        if (editing.getSource() != null) {
            List<CommandElement> commands = editing.getSource().getCommands();
            if (commands != null) {
                filter(commands);
                for (CommandElement command : commands) {
                    combo.addItem(command);
                }
            }
        }
        combo.addItem(J2MEBundle.message("ui.editor.EdgeEditorDialog.createCommand"));
        combo.setSelectedItem(editing.getCommand());
    }

    // only commands without edges
    private void filter(List<CommandElement> commands) {
        for (int i = commands.size() - 1; i >= 0; i--) {
            CommandElement command = commands.get(i);
            if (model.associatedEdge(command) != null) {
                commands.remove(command);
            }
        }
    }

    protected void performAction() {
        editing.setCommand(command);
    }

    public boolean validSelection() {
        return combo.getSelectedItem() != null;
    }

    public void actionPerformed(ActionEvent e) {
        JComboBox combo = (JComboBox) e.getSource();
        Object item = combo.getSelectedItem();

        // 'create...' option
        String value = J2MEBundle.message("ui.editor.EdgeEditorDialog.createCommand");
        if ((item instanceof String) && value.equals(item)) {
            NewCommandDialog dialog = new NewCommandDialog();
            dialog.show();
            if (dialog.isOK()) {
                command = dialog.selectedCommand();
                if (!model.propertyExists(command)) {
                    getSourceElement().add(command);
                    combo.addItem(command);
                    combo.setSelectedItem(command);
                    model.update();
                } else {
                    combo.setSelectedIndex(-1);
                    Messages.showErrorDialog(
                            J2MEBundle.message("ui.diagram.DuplicatedElementException.duplicatedElement",
                                    command.getLabel() + " (" + command.getProperty() + ")"),
                            J2MEBundle.message("ui.diagram.DuplicatedElementException.duplicatedElementTitle"));
                }
            }
        } else if (item instanceof CommandElement) {
            command = (CommandElement) item;
        }
    }
}
