/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.editor;

import com.intellij.openapi.ui.DialogWrapper;
import net.sourceforge.intellime.ui.diagram.DiagramGraphDataModel;

public abstract class EditorDialogBase<E> extends DialogWrapper {

    DiagramGraphDataModel model;
    protected E editing;

    protected abstract void performAction();

    protected abstract boolean validSelection();

    protected EditorDialogBase(DiagramGraphDataModel model, E editing) {
        super(false);
        this.model = model;
        this.editing = editing;
        setModal(true);
        init();
    }

    protected final void doOKAction() {
        if (validSelection()) {
            performAction();
            // close dialog
            super.doOKAction();
        }
    }

    public final boolean isOK() {
        return validSelection() && super.isOK();
    }
}
