/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.editor;

import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.diagram.DiagramGraphDataModel;
import net.sourceforge.intellime.ui.diagram.Edge;
import net.sourceforge.intellime.ui.diagram.Node;
import net.sourceforge.intellime.ui.element.J2MEElement;
import net.sourceforge.intellime.ui.element.TriggerElement;
import net.sourceforge.intellime.ui.element.command.CommandElement;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

public class NodeEditorDialog extends EditorDialogBase<Node> implements ActionListener {

    private JList list;
    private JPanel pane;
    private DefaultListModel listModel;

    public NodeEditorDialog(DiagramGraphDataModel model, Node editing) {
        super(model, editing);
        setTitle(J2MEBundle.message("ui.editor.NodeEditorDialog.title"));
        setModal(true);
        init();
    }

    public boolean isEmpty() {
        return editing.getScreenElement().getTriggerElements().size() == 0;
    }

    protected void performAction() {

    }

    protected boolean validSelection() {
        return true;
    }

    @Nullable
    protected JComponent createCenterPanel() {
        if (pane == null) {
            pane = new JPanel();
            pane.setLayout(new BorderLayout());

            JLabel label = new JLabel(J2MEBundle.message("ui.editor.NodeEditorDialog.caption"));
            pane.add(label, BorderLayout.NORTH);

            listModel = getModel();
            list = new JList(listModel);
            list.setSelectionMode(DefaultListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
            pane.add(new JScrollPane(list), BorderLayout.CENTER);

            JButton button = new JButton(J2MEBundle.message("ui.editor.NodeEditorDialog.button"));
            button.addActionListener(this);
            pane.add(button, BorderLayout.SOUTH);
        }
        return pane;
    }

    private DefaultListModel getModel() {
        DefaultListModel listModel = new DefaultListModel();

        java.util.List<TriggerElement> triggers = editing
                .getScreenElement().getTriggerElements();

        for (Object o : triggers) {
            listModel.addElement(o);
        }

        return listModel;
    }

    private CommandElement[] avaliableCommands() {
        CommandElement[] result = new CommandElement[0];

        java.util.List<CommandElement> commands = editing
                .getScreenElement().getCommands();

        if (commands != null && commands.size() > 0) {
            result = commands.toArray(result);
        }

        return result;
    }

    public void actionPerformed(ActionEvent actionEvent) {
        int[] indices = list.getSelectedIndices();
        for (int i = indices.length - 1; i >= 0; i--) {
            J2MEElement object = (J2MEElement) listModel.getElementAt(indices[i]);
            listModel.removeElementAt(indices[i]);
            editing.getScreenElement().remove(object);
            if (object instanceof CommandElement) {
                CommandElement command = (CommandElement) object;
                java.util.List<Edge> edges = (java.util.List<Edge>) model.getEdges();
                for (int j = edges.size() - 1; j >= 0; j--) {
                    Edge e = edges.get(j);
                    if (editing.equals(e.getSource()) && command.equals(e.getCommand())) {
                        model.removeEdge(e, false);
                    }
                }
            }
        }
        model.update();
    }
}
