/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.editor;

import net.sourceforge.intellime.J2MEBundle;
import net.sourceforge.intellime.ui.diagram.Edge;
import net.sourceforge.intellime.ui.diagram.Node;
import net.sourceforge.intellime.ui.element.command.CommandElement;

import javax.swing.table.AbstractTableModel;
import java.util.List;

public class NodeTableModel extends AbstractTableModel {

    private String[] titles = new String[]{
            J2MEBundle.message("ui.editor.NodeEditorDialog.commandTitle"),
            J2MEBundle.message("ui.editor.NodeEditorDialog.nodeTitle")
    };

    private Class[] classes = new Class[]{Object.class, Object.class};

    private Node editing;
    private List<Edge> edges;
    private Object[][] data;

    public NodeTableModel(Node editing, List<Edge> edges) {
        this.editing = editing;
        this.edges = edges;

        data = new Object[editing.getCommands().size()][2];

        int row = 0;
        for (CommandElement command : editing.getCommands()) {
            data[row][0] = command;
            for (Edge edge : edges) {
                // select corresponding target on combo
                if (command.equals(edge.getCommand())) {
                    data[row][1] = edge.getTarget();
                }
            }
            row++;
        }
    }

    public int getColumnCount() {
        return titles.length;
    }

    public int getRowCount() {
        return editing.getCommands().size();
    }

    public String getColumnName(int col) {
        return titles[col];
    }

    public Object getValueAt(int row, int col) {
        return data[row][col];
    }

    public Class getColumnClass(int c) {
        return classes[c];
    }

    public boolean isCellEditable(int row, int col) {
        return true;
    }

    public void setValueAt(Object value, int row, int col) {
        data[row][col] = value;
        fireTableCellUpdated(row, col);
    }
}

