/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.element;

import javax.swing.*;
import java.lang.reflect.Constructor;

public abstract class J2MEElementBase implements J2MEElement {

    private String label;
    private String property;

    public J2MEElementBase(String label, String property) {
        this.label = label;
        this.property = property;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String name) {
        this.label = name;
    }

    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }

    public Icon getIcon() {
        return null;
    }

    public String toString() {
        return label;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        J2MEElementBase that = (J2MEElementBase) o;

        if (property != null ? !property.equals(that.property) : that.property != null) return false;

        return true;
    }

    public int hashCode() {
        return (property != null ? property.hashCode() : 0);
    }

    public J2MEElement createCopy() {
        J2MEElement clone = null;
        String className = this.getClass().getName();

        if (className != null && !"".equals(className.trim())) {
            try {
                Class classe = Class.forName(className.trim());
                Constructor construtor = classe.getConstructor(new Class[]{String.class, String.class});
                if (construtor == null) {
                    clone = (J2MEElement) classe.newInstance();
                } else {
                    clone = (J2MEElement) construtor.newInstance(new Object[]{this.getLabel(), this.getProperty()});
                }
            }
            catch (Exception e) {
                e.printStackTrace();
            }
        }

        return clone;
    }
}
