/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.element.screen;

import net.sourceforge.intellime.ui.element.J2MEElement;
import net.sourceforge.intellime.ui.element.J2MEElementBase;
import net.sourceforge.intellime.ui.element.NestedListElement;
import net.sourceforge.intellime.ui.element.TriggerElement;
import net.sourceforge.intellime.ui.element.command.CommandElement;
import net.sourceforge.intellime.ui.element.item.ItemElement;

import java.util.ArrayList;
import java.util.List;

public abstract class ScreenElement extends J2MEElementBase {

    private List<J2MEElement> elements = new ArrayList<J2MEElement>();

    public ScreenElement(String label, String property) {
        super(label, property);
    }

    public void add(J2MEElement element) {
        elements.add(element);
    }

    public boolean remove(J2MEElement element) {
        return elements.remove(element);
    }

    public boolean contains(J2MEElement element) {
        return elements.contains(element);
    }

    public List<TriggerElement> getTriggerElements() {
        List<TriggerElement> triggers = new ArrayList<TriggerElement>();
        for (J2MEElement element : this.elements) {
            if (element instanceof TriggerElement) {
                triggers.add((TriggerElement) element);
            }
        }
        return triggers;
    }

    public List<CommandElement> getCommands() {
        List<CommandElement> commands = new ArrayList<CommandElement>();
        for (J2MEElement element : elements) {
            if (element instanceof CommandElement) {
                commands.add((CommandElement) element);
            }
        }
        return commands;
    }

    public List<ItemElement> getItems() {
        List<ItemElement> items = new ArrayList<ItemElement>();
        for (J2MEElement element : elements) {
            if (element instanceof ItemElement) {
                items.add((ItemElement) element);
            }
        }
        return items;
    }

    public List<NestedListElement> getNestedListElements() {
        List<NestedListElement> nestedListElements = new ArrayList<NestedListElement>();
        for (J2MEElement element : elements) {
            if (element instanceof NestedListElement) {
                nestedListElements.add((NestedListElement) element);
            }
        }
        return nestedListElements;
    }

    public List<J2MEElement> getElements() {
        return elements;
    }

}
