/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.outlook;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

public class OutlookBar extends JPanel implements ActionListener {

    private int index = 0;
    private List<OutlookPanel> panels = new ArrayList<OutlookPanel>();
    private JPanel topPanel = new JPanel();
    private JPanel bottonPanel = new JPanel();
    private JPanel currentPanel = new JPanel();
    private GridLayout layoutTop = new GridLayout(1, 1);
    private GridLayout layoutBotton = new GridLayout(1, 1);

    public OutlookBar() {
        this.setLayout(new BorderLayout());
        topPanel.setLayout(layoutTop);
        currentPanel.setLayout(new BorderLayout());
        bottonPanel.setLayout(layoutBotton);
        this.add(topPanel, BorderLayout.NORTH);
        this.add(currentPanel, BorderLayout.CENTER);
        this.add(bottonPanel, BorderLayout.SOUTH);
    }

    public OutlookPanel addPane(String title) {
        return addPane(title, null);
    }

    public OutlookPanel addPane(String title, Icon icon) {
        OutlookPanel panel = new OutlookPanel(title, icon);
        panel.getButton().addActionListener(this);
        panels.add(panel);
        draw();

        return panel;
    }

    public void actionPerformed(ActionEvent e) {
        JButton button = (JButton) e.getSource();
        updateIndex(button);
        draw();
    }

    private void updateIndex(JButton button) {
        int i = 0;
        for (OutlookPanel op : panels) {
            if (op.getButton() == button) {
                index = i;
            }
            i++;
        }
    }

    private void draw() {
        topPanel.removeAll();
        currentPanel.removeAll();
        bottonPanel.removeAll();

        layoutTop.setRows(index + 1);
        int i = 0;
        for (; i <= index; i++) {
            topPanel.add(panels.get(i).getButton());
        }

        layoutBotton.setRows(panels.size() - index - 1);
        for (; i < panels.size(); i++) {
            bottonPanel.add(panels.get(i).getButton());
        }

        OutlookPanel panel = panels.get(index);
        currentPanel.add(panel.getComponent(), BorderLayout.CENTER);

        this.validate();
    }
} 
