/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.outlook;

import net.sourceforge.intellime.ui.UiUtils;
import net.sourceforge.intellime.ui.element.J2MEElement;

import javax.swing.*;
import javax.swing.border.BevelBorder;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

public class OutlookPanel {
    private JButton button;
    private JScrollPane scroll;
    private ButtonGroup group = new ButtonGroup();
    private JPanel buttonPane = new JPanel();
    private GridLayout layout = new GridLayout(1, 1);
    private JToggleButton selected = null;
    private Border raised = BorderFactory.createBevelBorder(BevelBorder.RAISED);
    private Border lowered = BorderFactory.createBevelBorder(BevelBorder.LOWERED);
    private Border empty = new EmptyBorder(5, 5, 0, 0);

    public OutlookPanel(String title) {
        this(title, null);
    }

    public OutlookPanel(String title, Icon icon) {
        this.button = UiUtils.createButton(title, icon);
        initialize();
    }

    public JButton getButton() {
        return button;
    }

    public JComponent getComponent() {
        return scroll;
    }

    private void initialize() {
        JPanel panel = new JPanel();
        panel.setLayout(new BorderLayout());

        buttonPane.setLayout(layout);

        panel.add(buttonPane, BorderLayout.NORTH);
        panel.add(new JPanel(), BorderLayout.CENTER);

        scroll = new JScrollPane(panel);
    }

    public void addComand(J2MEElement element) {
        layout.setRows(layout.getRows() + 1);
        JToggleButton toggle = UiUtils.createDragToggle(element);
        group.add(toggle);
        buttonPane.add(toggle);
        toggle.addMouseListener(adapter);
        toggle.addMouseListener(click);
    }

    MouseAdapter adapter = new MouseAdapter() {
        public void mouseEntered(MouseEvent e) {
            JToggleButton button = (JToggleButton) e.getSource();
            if (!button.isSelected()) {
                button.setBorder(raised);
            }
        }

        public void mouseExited(MouseEvent e) {
            JToggleButton button = (JToggleButton) e.getSource();
            if (!button.isSelected()) {
                button.setBorder(empty);
            }
        }
    };

    MouseAdapter click = new MouseAdapter() {
        public void mousePressed(MouseEvent e) {
            JToggleButton button = (JToggleButton) e.getSource();
            selectButton(button);
        }
    };

    private void selectButton(JToggleButton button) {
        if (selected != null) {
            selected.setSelected(false);
            selected.setBorder(empty);
        }
        button.setSelected(true);
        button.setBorder(lowered);
        selected = button;
    }

    public String toString() {
        return button == null ? null : button.getText();
    }
}
