/*
 * Copyright 2000-2006 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.ui.wizard.core;

import com.intellij.ui.DocumentAdapter;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.text.JTextComponent;
import java.awt.*;
import java.util.ArrayList;

public class WizardPage {

    public final static WizardPage[] EMPTY_ARRAY = new WizardPage[0];

    private ChangeListener listener;
    private final Component component;
    private final String caption;
    private String helpId;
    private final DocumentListener docListener;
    private final ArrayList<JTextComponent> required;

    private boolean enabled = true;

    public WizardPage(Component component, String caption) {
        this(component, caption, null);
    }

    public WizardPage(Component component, String caption, String helpId) {

        this.component = component;
        this.caption = caption;
        this.helpId = helpId;
        this.docListener = new DocumentAdapter() {
            protected void textChanged(DocumentEvent e) {
                listener.stateChanged(new ChangeEvent(this));
            }
        };
        this.required = new ArrayList<JTextComponent>();
    }

    public Component getComponent() {
        return component;
    }

    public void addChangeListener(ChangeListener listener) {
        this.listener = listener;
    }

    public void addRequired(JTextComponent c) {
        c.getDocument().addDocumentListener(docListener);
        required.add(c);
    }

    public boolean isValid() {
        for (Object aRequired : required) {
            if (((JTextComponent) aRequired).getText().trim().length() == 0) {
                return false;
            }
        }
        return true;
    }

    public String getCaption() {
        return caption;
    }

    public String getHelpId() {
        return helpId;
    }

    public boolean isEnabled() {
        return enabled;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }
}
