/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.util;

import com.intellij.lang.StdLanguages;
import com.intellij.openapi.fileTypes.LanguageFileType;
import com.intellij.openapi.vfs.VirtualFile;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

public class FileTypeBase extends LanguageFileType {

    private final String name;
    private final String description;
    private final String defaultExtension;
    private final Icon icon;

    public FileTypeBase(String name, String description, String defaultExtension, Icon icon) {
        super(StdLanguages.XML);
        this.name = name;
        this.description = description;
        this.defaultExtension = defaultExtension;
        this.icon = icon;
    }

    @NotNull
    public String getName() {
        return name;
    }

    @NotNull
    public String getDescription() {
        return description;
    }

    public String[] getAssociatedExtensions() {
        return new String[]{defaultExtension};
    }

    @NotNull
    public String getDefaultExtension() {
        return defaultExtension;
    }

    public Icon getIcon(VirtualFile file) {
        return null;
    }

    public Icon getIcon() {
        return icon;
    }

}
