/*
 * Copyright 2006 IntelliME.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.intellime.util;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.PsiDocumentManager;
import com.intellij.psi.PsiManager;

import java.io.IOException;
import java.io.StringWriter;
import java.util.Arrays;
import java.util.Map;

public class Utils {

    private static final String[] RESERVED_WORDS = new String[]{
            "abstract", "assert", "boolean", "break", "byte", "case", "catch", "char",
            "class", "const", "continue", "default", "do", "double", "else", "enum",
            "extends", "final", "finally", "float", "for", "goto", "if", "implements",
            "import", "instanceof", "int", "interface", "long", "native", "new", "package",
            "private", "protected", "public", "return", "short", "static", "strictfp",
            "super", "switch", "synchronized", "this", "throw", "throws", "transient ",
            "try", "void", "volatile", "while"};

    public static boolean isDiagramFile(VirtualFile file) {
        return file != null &&
                file.getExtension() != null &&
                Constants.DIAGRAM_FILE_EXTENSION.equalsIgnoreCase(file.getExtension());
    }

    public static boolean isJavaIdentifier(String s) {
        boolean result = true;
        if (s != null && s.length() > 0 && Character.isJavaIdentifierStart(s.charAt(0))) {
            for (int i = 1; i < s.length() && result; i++) {
                if (!Character.isJavaIdentifierPart(s.charAt(i))) {
                    result = false;
                }
            }
        } else {
            result = false;
        }

        return result && Arrays.binarySearch(RESERVED_WORDS, s) < 0;
    }

    public static boolean isValidPackage(String s) {
        boolean isValid;

        if ("".equals(s.trim())) {
            isValid = true;
        } else {
            isValid = ("".equals(s) || s.matches("^[a-zA-Z][a-zA-Z0-9]*(\\.[a-zA-Z_][a-zA-Z0-9_]*)*$"));
        }
        return isValid;
    }

    public static boolean isFileEmpty(Project project, VirtualFile file) {
        return PsiDocumentManager.getInstance(project).getDocument(
                PsiManager.getInstance(project).findFile(file)).getTextLength() == 0;
    }

    public static String getTemplateEvaluateAsString(String templateName, Map<String, Object> parameters) throws IOException, Template.TemplateException {
        Template t = new Template(templateName);
        StringWriter writer = new StringWriter();

        for (Map.Entry<String, Object> entry : parameters.entrySet()) {
            t.put(entry.getKey(), entry.getValue());
        }

        t.evaluate(writer);
        return writer.toString();
    }
}
